define(
//begin v1.x content
({
	insertImageTitle: "Grafik einfügen",
	url: "Grafik",
	browse: "Durchsuchen...",
	text: "Beschreibung",
	set: "Einfügen",
	invalidMessage: "Ungültiger Grafikdateityp",
	prePopuTextUrl: "Geben Sie eine gültige Grafik-URL ein",
	prePopuTextBrowse: "oder blättern Sie zu einer lokalen Datei."
})

//end v1.x content
);
